@@ -1,50 +1,5 @@
 
 
-#' Change the hierarchy table to follow the standard
-#'
-#' Make sure that variable names and sign coding follow an internal standard. Level may be computed automatically
-#'
-#' @encoding UTF8
-#'
-#' @param hierarchy data frame with hierarchy table
-#' @param hierarchyVarNames variable names
-#' @param autoLevel When TRUE, level is computed by automatic method
-#'
-#' @return data frame with hierarchy table
-#' @export
-#' @author Øyvind Langsrud
-#'
-#' @examples
-#' # Make input data by changing variable names and sign coding.
-#' h <- SSBtoolsData("FIFA2018ABCD")[, 1:3]
-#' names(h)[1:2] <- c("from", "to")
-#' minus <- h$sign < 0
-#' h$sign <- "+"
-#' h$sign[minus] <- "-"
-#'
-#' # Run HierarchyFix - Two levels created
-#' HierarchyFix(h, c(mapsFrom = "from", mapsTo = "to", sign = "sign"))
-#'
-#' # Extend the hierarchy table
-#' h2 <- rbind(data.frame(from = c("Oceania", "Asia", "Africa", "America", "Europe"),
-#'                        to = "World", sign = "+"),
-#'            data.frame(from = c("World", "Europe"),
-#'                       to = "nonEurope", sign = c("+", "-")), h)
-#'
-#' # Run HierarchyFix - Three levels created
-#' HierarchyFix(h2, c(mapsFrom = "from", mapsTo = "to", sign = "sign"))
-#'
-HierarchyFix <- function(hierarchy, hierarchyVarNames = c(mapsFrom = "mapsFrom", mapsTo = "mapsTo", sign = "sign", level = "level"), autoLevel = TRUE) {
-  h <- FixHierarchy(hierarchy, hierarchyVarNames)
-  if (autoLevel) 
-    h <- AutoLevel(h)
-  h
-}
-
-
-
-
-
 #' Hierarchical Computations
 #'
 #' This function computes aggregates by crossing several hierarchical specifications and factorial variables.
@@ -731,15 +686,50 @@ HierarchyCompute <- function(data, hierarchies, valueVar,
 
 
 
-#' AddMapsInput
+
+#' Change the hierarchy table to follow the standard
 #'
-#' Brukes til å generere feil
+#' Make sure that variable names and sign coding follow an internal standard. Level may be computed automatically
 #'
-#' @param hierarchies hierarchies
-#' @param data data
+#' @encoding UTF8
 #'
+#' @param hierarchy data frame with hierarchy table
+#' @param hierarchyVarNames variable names
+#' @param autoLevel When TRUE, level is computed by automatic method
+#'
+#' @return data frame with hierarchy table
 #' @keywords internal
+#' @export
+#' @author Øyvind Langsrud
 #'
+#' @examples
+#' # Make input data by changing variable names and sign coding.
+#' h <- SSBtoolsData("FIFA2018ABCD")[, 1:3]
+#' names(h)[1:2] <- c("from", "to")
+#' minus <- h$sign < 0
+#' h$sign <- "+"
+#' h$sign[minus] <- "-"
+#'
+#' # Run HierarchyFix - Two levels created
+#' HierarchyFix(h, c(mapsFrom = "from", mapsTo = "to", sign = "sign"))
+#'
+#' # Extend the hierarchy table
+#' h2 <- rbind(data.frame(from = c("Oceania", "Asia", "Africa", "America", "Europe"),
+#'                        to = "World", sign = "+"),
+#'            data.frame(from = c("World", "Europe"),
+#'                       to = "nonEurope", sign = c("+", "-")), h)
+#'
+#' # Run HierarchyFix - Three levels created
+#' HierarchyFix(h2, c(mapsFrom = "from", mapsTo = "to", sign = "sign"))
+#'
+HierarchyFix <- function(hierarchy, hierarchyVarNames = c(mapsFrom = "mapsFrom", mapsTo = "mapsTo", sign = "sign", level = "level"), autoLevel = TRUE) {
+  h <- FixHierarchy(hierarchy, hierarchyVarNames)
+  if (autoLevel) 
+    h <- AutoLevel(h)
+  h
+}
+
+
 AddMapsInput <- function(hierarchies, data = NULL) {
   for (i in length(hierarchies)) {
     if (is.list(hierarchies[[i]])) {
@@ -761,14 +751,6 @@ AddMapsInput <- function(hierarchies, data = NULL) {
 
 
 
-#' AddNonExistingCode
-#'
-#' @param hierarchies hierarchies
-#' @param data data
-#' @param rowSelect rowSelect
-#'
-#' @keywords internal
-#'
 AddNonExistingCode <- function(hierarchies, rowSelect = NULL, inputInOutput = TRUE) {
   if (is.null(rowSelect)) 
     return(hierarchies)
@@ -799,16 +781,6 @@ AddNonExistingCode <- function(hierarchies, rowSelect = NULL, inputInOutput = TR
 
 
 
-
-#' CrossDataDummyHierarchies
-#'
-#' @param dataDummyHierarchies dataDummyHierarchies
-#' @param codeFrames codeFrames
-#' @param makeDimnames makeDimnames
-#' @param removeEmpty removeEmpty
-#' @param verbose Whether to print information during calculations. FALSE is default.
-#' @keywords internal
-#'
 CrossDataDummyHierarchies <- function(dataDummyHierarchies, codeFrames = NULL, makeDimnames = FALSE, useMatrixToDataFrame = TRUE, 
                                       removeEmpty = FALSE, verbose = FALSE, reOrder = FALSE) {
   
@@ -1047,211 +1019,6 @@ AutoLevel <- function(x) {
 
 
 
-
-#' Converting hierarchy specifications to a (signed) dummy matrix
-#'
-#' A matrix for mapping input codes (columns) to output codes (rows) are created.
-#' The elements of the matrix specify how columns contribute to rows.
-#'
-#'
-#' @param mapsFrom Character vector from hierarchy table
-#' @param mapsTo Character vector from hierarchy table
-#' @param sign  Numeric vector of either 1 or -1 from hierarchy table
-#' @param level Numeric vector from hierarchy table
-#' @param mapsInput All codes in mapsFrom not in mapsTo (created automatically when NULL) and possibly other codes in input data.
-#' @param inputInOutput When FALSE all output rows represent codes in mapsTo
-#' @param keepCodes To prevent some codes to be removed when inputInOutput = FALSE
-#' @param unionComplement When TRUE, sign means union and complement instead of addition or subtraction (see note)
-#' @param reOrder When TRUE (FALSE is default) output codes are ordered differently, more similar to a usual model matrix ordering.
-#'
-#' @return
-#' A sparse matrix with row and column and names
-#' @export
-#' @author Øyvind Langsrud
-#' @import Matrix
-#'
-#' @note
-#' With unionComplement = FALSE (default), the sign of each mapping specifies the contribution as addition or subtraction.
-#' Thus, values above one and negative values in output can occur.
-#' With unionComplement = TRUE,  positive is treated as union and negative as complement. Then 0 and 1 are the only possible elements in the output matrix.
-#'
-#' @examples
-#' # A hierarchy table
-#' h <- SSBtoolsData("FIFA2018ABCD")
-#'
-#' DummyHierarchy(h$mapsFrom, h$mapsTo, h$sign, h$level)
-#' DummyHierarchy(h$mapsFrom, h$mapsTo, h$sign, h$level, inputInOutput = TRUE)
-#' DummyHierarchy(h$mapsFrom, h$mapsTo, h$sign, h$level, keepCodes = c("Portugal", "Spain"))
-#'
-#' # Extend the hierarchy table to illustrate the effect of unionComplement
-#' h2 <- rbind(data.frame(mapsFrom = c("EU", "Schengen"), mapsTo = "EUandSchengen", 
-#'                        sign = 1, level = 3), h)
-#'
-#' DummyHierarchy(h2$mapsFrom, h2$mapsTo, h2$sign, h2$level)
-#' DummyHierarchy(h2$mapsFrom, h2$mapsTo, h2$sign, h2$level, unionComplement = TRUE)
-#'
-#' # Extend mapsInput - leading to zero columns.
-#' DummyHierarchy(h$mapsFrom, h$mapsTo, h$sign, h$level,
-#'                mapsInput = c(h$mapsFrom[!(h$mapsFrom %in% h$mapsTo)], "Norway", "Finland"))
-#'
-#' # DummyHierarchies
-#' DummyHierarchies(FindHierarchies(SSBtoolsData("sprt_emp_withEU")[, c("geo", "eu", "age")]), 
-#'                  inputInOutput = c(FALSE, TRUE))
-DummyHierarchy <- function(mapsFrom, mapsTo, sign, level, mapsInput = NULL, inputInOutput = FALSE, keepCodes = mapsFrom[integer(0)], unionComplement = FALSE, reOrder = FALSE) {
-  
-  mapsFrom <- as.character(mapsFrom)  # Ensure character (if factor)
-  mapsTo <- as.character(mapsTo)  # Ensure character (if factor)
-  
-  if (is.null(mapsInput)) 
-    mapsInput <- mapsFrom[!(mapsFrom %in% mapsTo)]
-  
-  mapsInput <- sort(as.factor(unique(mapsInput)))
-  
-  m <- Matrix::t(fac2sparse(mapsInput))
-  rownames(m) <- as.character(mapsInput)  #dimnames(m)[[2]]  = as.character(mapsInput)
-  
-  dropInput <- rownames(m)
-  if (length(keepCodes) > 0) 
-    dropInput <- dropInput[!(dropInput %in% keepCodes)]
-  
-  nInput <- dim(m)[1]
-  
-  for (i in unique(sort(level))) {
-    ri <- (level == i)
-    mapsToi <- factor(mapsTo[ri])
-    mapsFromi <- factor(mapsFrom[ri], levels = rownames(m))
-    
-    if (anyNA(mapsFromi)) {
-      warning("Problematic hierarchy specification")
-    }
-    mNew <- Matrix(0, NROW(m), length(levels(mapsToi)), dimnames = list(levels(mapsFromi), levels(mapsToi)))
-    mNew[cbind(as.integer(mapsFromi), as.integer(mapsToi))] <- sign[ri]
-    if(reOrder){
-      if (unionComplement) 
-        m <- rbind(CrossprodUnionComplement(mNew, m),m)  #  Better ordering 
-      else m <- rbind(Mult_crossprod(mNew, m),m) #rbind(crossprod(mNew, m),m)  
-    } else {
-      if (unionComplement) 
-        m <- rbind(m, CrossprodUnionComplement(mNew, m))  # Matrix::rBind(m,  CrossprodUnionComplement(mNew,m))
-      else m <- rbind(m, Mult_crossprod(mNew, m)) #rbind(m, crossprod(mNew, m))  # Matrix::rBind(m,  crossprod(mNew,m))
-    }
-  }
-  if (is.list(inputInOutput)) {   # When list: Extended use of inputInOutput (hack)
-    inputInOutput <- inputInOutput[[1]]
-    if (is.character(inputInOutput)) {
-      ma <- match(inputInOutput, rownames(m))
-      if (anyNA(ma)) {
-        warning(paste("Output codes not found in the hierarchy result in empties:", 
-                      paste(HeadEnd(inputInOutput[is.na(ma)]), collapse = ", ")))
-        m0 <- Matrix(0, sum(is.na(ma)), ncol(m))
-        rownames(m0) <- inputInOutput[is.na(ma)]
-        m <- rbind(m, m0)
-        ma <- match(inputInOutput, rownames(m))
-      }
-      m <- m[ma, , drop = FALSE]
-      return(m)
-    }
-  }
-  if (!inputInOutput & length(dropInput) > 0) {
-    keepRows <- rownames(m)[!(rownames(m) %in% dropInput)]
-    m <- m[keepRows, , drop = FALSE]
-  }
-  m  # Lage warnig/error om annet i matrisa enn 0, -1, 1 ?
-}
-
-#' @rdname DummyHierarchy
-#' @details `DummyHierarchies` is a user-friendly wrapper for the original function `DummyHierarchy`.
-#'           Then, the logical input parameters are vectors (possibly recycled).
-#'           `mapsInput` and `keepCodes` can be supplied as attributes.
-#'           `mapsInput` will be generated when `data` is non-NULL.   
-#'            
-#' 
-#' @param hierarchies  List of hierarchies
-#' @param data data
-#' @export
-DummyHierarchies <- function(hierarchies, data = NULL, inputInOutput = FALSE, unionComplement = FALSE, reOrder = FALSE) {
-  
-  n <- length(hierarchies)
-  inputInOutput <- rep_len(inputInOutput, n)
-  unionComplement <- rep_len(unionComplement, n)
-  reOrder <- rep_len(reOrder, n)
-  
-  
-  for (i in seq_len(n)) {
-    if (!is.null(data)) {
-      hierarchies[i] <- AddMapsInput(hierarchies[i], data)
-    }
-    
-    hierarchies[[i]] <- DummyHierarchy(mapsFrom = hierarchies[[i]]$mapsFrom, 
-                                       mapsTo = hierarchies[[i]]$mapsTo, 
-                                       mapsInput = attr(hierarchies[[i]], "mapsInput"),
-                                       keepCodes = attr(hierarchies[[i]], "keepCodes"), 
-                                       sign = hierarchies[[i]]$sign, 
-                                       level = hierarchies[[i]]$level, 
-                                       inputInOutput = inputInOutput[i],
-                                       unionComplement = unionComplement[i], 
-                                       reOrder = reOrder[i])
-  }
-  hierarchies
-}
-
-
-
-#' Create a (signed) dummy matrix for hierarcical mapping of codes in data
-#'
-#' @param dataVector A vector of codes in data
-#' @param dummyHierarchy Output from \code{\link{DummyHierarchy}}
-#'
-#' @return  A sparse matrix.
-#' Column names are taken from dataVector (if non-NULL) and row names are taken from
-#' the row names of dummyHierarchy.
-#' @export
-#' @author Øyvind Langsrud
-#'
-DataDummyHierarchy <- function(dataVector, dummyHierarchy) {
-  x <- factor(dataVector, levels = colnames(dummyHierarchy))
-  m <- dummyHierarchy[, as.integer(x), drop = FALSE]
-  colnames(m) <- names(dataVector)
-  m
-}
-
-
-
-#' @rdname DataDummyHierarchy
-#' @details `DataDummyHierarchies` is a user-friendly wrapper for the original function `DataDummyHierarchy`.
-#'          When `colNamesFromData` is `FALSE` (default), this function returns
-#'          `mapply(DataDummyHierarchy,` `data[names(dummyHierarchies)],` `dummyHierarchies)`. 
-#'            
-#' @param data data
-#' @param dummyHierarchies  Output from \code{\link{DummyHierarchies}}
-#' @param colNamesFromData  Column names from data when `TRUE` 
-#' @export
-#' @examples
-#' z <- SSBtoolsData("sprt_emp_withEU")[1:9, ]
-#' hi <- FindHierarchies(z[, c("geo", "eu", "age", "year")])
-#' dhi <- DummyHierarchies(hi, inputInOutput = TRUE)
-#' DataDummyHierarchies(z, dhi, colNamesFromData = TRUE)
-DataDummyHierarchies <- function(data, dummyHierarchies,  colNamesFromData = FALSE) {
-  
-  if(!colNamesFromData)
-    return(mapply(DataDummyHierarchy, data[names(dummyHierarchies)], dummyHierarchies))
-  
-  mapply(function(a, b){names(a) <- a; DataDummyHierarchy(a,b)}, data[names(dummyHierarchies)], dummyHierarchies)
-  
-}
-
-
-
-#' CrossDataDummyHierarchy
-#'
-#' @param dataDummyHierarchy1 dataDummyHierarchy1
-#' @param dataDummyHierarchy2 dataDummyHierarchy2
-#' @param codeFrame1 codeFrame1
-#' @param codeFrame2 codeFrame2
-#' @param makeDimnames makeDimnames
-#'
-#' @keywords internal
-#'
 CrossDataDummyHierarchy <- function(dataDummyHierarchy1, dataDummyHierarchy2 = NULL, codeFrame1 = NULL, codeFrame2 = NULL, makeDimnames = FALSE, useMatrixToDataFrame = TRUE) {
   if (is.null(dataDummyHierarchy2)) {
     if (is.null(codeFrame1)) 
@@ -1316,8 +1083,6 @@ GetFirstStringInList <- function(x) {
 }
 
 
-
-
 KhatriRaoReOrder = function(x,y,make.dimnames = FALSE){
   a <- nrow(x)
   b <- nrow(y)
